==> nextcloud-28.0.3.tgz: nextcloud/apps/federation/l10n/sk.js <==
OC.L10N.register(
    "federation",
    {
    "Added to the list of trusted servers" : "Pridané do zoznamu dôveryhodných serverov",
    "Server is already in the list of trusted servers." : "Server sa už nachádza v zozname dôveryhodných serverov",
    "No server to federate with found" : "Server pre združenie sa nenašiel",
    "Could not add server" : "Nebolo možné pridať server",
    "Trusted servers" : "Dôveryhodné servery",
    "Federation" : "Združovanie",
    "+ Add trusted server" : "Pridať dôveryhodný server",
    "Trusted server" : "Dôveryhodný server",
    "Add" : "Pridať",
    "Federation allows you to connect with other trusted servers to exchange the user directory." : "Združovanie vám umožňuje sa pripojiť k iným dôveryhodným serverom za účelom výmeny adresára používateľov.",
    "Federation allows you to connect with other trusted servers to exchange the user directory. For example this will be used to auto-complete external users for federated sharing." : "Združovanie vám umožňuje sa pripojiť k iným dôveryhodným serverom za účelom výmeny adresára používateľov. Používa sa to napr. pre automatické doplňovanie používateľov pri združenom zdieľaní.",
    "Federation allows you to connect with other trusted servers to exchange the user directory. For example this will be used to auto-complete external users for federated sharing. It is not necessary to add a server as trusted server in order to create a federated share." : "Združovanie vám umožňuje sa pripojiť k iným dôveryhodným serverom za účelom výmeny adresára používateľov. Používa sa to napr. pre automatické doplňovanie používateľov pri združenom zdieľaní. Na vytvorenie zdieľaného adresára nie je potrebné pridať server ako dôveryhodný server."
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-28.0.9.tgz: nextcloud/apps/federation/l10n/sk.js <==
OC.L10N.register(
    "federation",
    {
    "Added to the list of trusted servers" : "Pridané do zoznamu dôveryhodných serverov",
    "Server is already in the list of trusted servers." : "Server sa už nachádza v zozname dôveryhodných serverov",
    "No server to federate with found" : "Server pre združenie sa nenašiel",
    "Could not add server" : "Nebolo možné pridať server",
    "Trusted servers" : "Dôveryhodné servery",
    "Federation" : "Združovanie",
    "Federation allows you to connect with other trusted servers to exchange the account directory." : "Združovanie vám umožňuje sa pripojiť k iným dôveryhodným serverom za účelom výmeny účtov.",
    "Federation allows you to connect with other trusted servers to exchange the account directory. For example this will be used to auto-complete external accounts for federated sharing." : "Združovanie vám umožňuje sa pripojiť k iným dôveryhodným serverom za účelom výmeny účtov. Používa sa to napr. pre automatické doplňovanie externých účtov pri združenom zdieľaní.",
    "Federation allows you to connect with other trusted servers to exchange the account directory. For example this will be used to auto-complete external accounts for federated sharing. It is not necessary to add a server as trusted server in order to create a federated share." : "Združovanie vám umožňuje sa pripojiť k iným dôveryhodným serverom za účelom výmeny zoznamu užívateľov. Používa sa to napr. pre automatické doplňovanie externých účtov pri združenom zdieľaní. Na vytvorenie združeného zdieľaného adresára nie je potrebné pridať server ako dôveryhodný server.",
    "+ Add trusted server" : "Pridať dôveryhodný server",
    "Trusted server" : "Dôveryhodný server",
    "Add" : "Pridať",
    "Federation allows you to connect with other trusted servers to exchange the user directory." : "Združovanie vám umožňuje sa pripojiť k iným dôveryhodným serverom za účelom výmeny adresára používateľov.",
    "Federation allows you to connect with other trusted servers to exchange the user directory. For example this will be used to auto-complete external users for federated sharing." : "Združovanie vám umožňuje sa pripojiť k iným dôveryhodným serverom za účelom výmeny adresára používateľov. Používa sa to napr. pre automatické doplňovanie používateľov pri združenom zdieľaní.",
    "Federation allows you to connect with other trusted servers to exchange the user directory. For example this will be used to auto-complete external users for federated sharing. It is not necessary to add a server as trusted server in order to create a federated share." : "Združovanie vám umožňuje sa pripojiť k iným dôveryhodným serverom za účelom výmeny adresára používateľov. Používa sa to napr. pre automatické doplňovanie používateľov pri združenom zdieľaní. Na vytvorenie zdieľaného adresára nie je potrebné pridať server ako dôveryhodný server."
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
